==> terasoluna-batch4j-sample-on-webapserver_2.0.0.1.zip: jp/terasoluna/fw/batch/commonj/WorkerExecutorService.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.fw.batch.commonj;

import java.util.LinkedHashMap;

import jp.terasoluna.fw.batch.commonj.listener.WorkMapListener;
import jp.terasoluna.fw.batch.core.JobException;
import jp.terasoluna.fw.batch.core.JobExceptionHandler;
import jp.terasoluna.fw.batch.core.JobStatus;
import jp.terasoluna.fw.batch.core.WorkQueue;
import jp.terasoluna.fw.batch.standard.QueueProcessor;

import commonj.work.WorkItem;
import commonj.work.WorkManager;


/**
 * [J[sT[rX(commonJ)̃C^tF[XB
 *
 *
 */
public interface WorkerExecutorService {
    /**
     * ftHgOnh̎擾B
     * 
     * @return ftHgOnh
     */
    JobExceptionHandler getDefaultJobExceptionHandler();

    /**
     * Onhi[Map̎擾B
     * 
     * @return Onhi[}bv
     */
    LinkedHashMap<JobException, JobExceptionHandler> getExceptionHandlerMap();

    /**
     * [N}l[W̎擾B
     * 
     * @return [N}l[W
     */
    WorkManager getWorkManager();

    /**
     * [NXi[̎擾B
     * 
     * @return [NXi[
     */
    WorkMapListener getWorkMapListener();
    
    /**
     * Worker̎so^B
     * 
     * @param queueProcessor L[vZbT
     * @param workQueue L[
     * @param jobStatus WuXe[^X
     * @return [J̏ʂɔ񓯊ŃANZX߂̃[NACe
     */
     WorkItem submit(QueueProcessor queueProcessor,
            WorkQueue workQueue, JobStatus jobStatus);

}

==> terasoluna-batch4j-sample-on-webapserver_2.0.0.4.zip: jp/terasoluna/fw/batch/commonj/WorkerExecutorService.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.fw.batch.commonj;

import java.util.LinkedHashMap;

import jp.terasoluna.fw.batch.commonj.listener.WorkMapListener;
import jp.terasoluna.fw.batch.core.JobException;
import jp.terasoluna.fw.batch.core.JobExceptionHandler;
import jp.terasoluna.fw.batch.core.JobStatus;
import jp.terasoluna.fw.batch.core.WorkQueue;
import jp.terasoluna.fw.batch.standard.QueueProcessor;

import commonj.work.WorkItem;
import commonj.work.WorkManager;


/**
 * [J[sT[rX(commonJ)̃C^tF[XB
 *
 *
 */
public interface WorkerExecutorService {
    /**
     * ftHgOnh̎擾B
     * 
     * @return ftHgOnh
     */
    JobExceptionHandler getDefaultJobExceptionHandler();

    /**
     * Onhi[Map̎擾B
     * 
     * @return Onhi[}bv
     */
    LinkedHashMap<JobException, JobExceptionHandler> getExceptionHandlerMap();

    /**
     * [N}l[W̎擾B
     * 
     * @return [N}l[W
     */
    WorkManager getWorkManager();

    /**
     * [NXi[̎擾B
     * 
     * @return [NXi[
     */
    WorkMapListener getWorkMapListener();
    
    /**
     * Worker̎so^B
     * 
     * @param queueProcessor L[vZbT
     * @param workQueue L[
     * @param jobStatus WuXe[^X
     * @return [J̏ʂɔ񓯊ŃANZX邽߂̃[NACe
     */
     WorkItem submit(QueueProcessor queueProcessor,
            WorkQueue workQueue, JobStatus jobStatus);

}
